# qt-range-slider ![GitHub tag (latest SemVer pre-release)](https://img.shields.io/github/v/tag/introkun/qt-range-slider) [![Build Status](https://github.com/introkun/qt-range-slider/workflows/CI/badge.svg)](https://github.com/introkun/qt-range-slider/actions?query=workflow%3ACI) [![Coverage Status](https://coveralls.io/repos/github/introkun/qt-range-slider/badge.svg?branch=main&dummy=unused)](https://coveralls.io/github/introkun/qt-range-slider?branch=main) [![GitHub license](https://img.shields.io/github/license/introkun/qt-range-slider.svg)](https://github.com/introkun/qt-range-slider/blob/main/LICENSE) [![PyPi Downloads](https://img.shields.io/pypi/dm/qt-range-slider)](https://pypi.org/project/qt-range-slider/)

# Demo
<img src="https://github.com/introkun/qt-range-slider/blob/main/assets/demo.png?raw=true" alt="Demo of qt-range-slider" style="width: 640px;"/>
